
use std::convert::Infallible;
use std::path::PathBuf;

mod ext; use ext::*;
mod pool;
mod handle;

#[tokio::main]
async fn main() {
    //TODO: Is one hashing handler enough? Or should we have a pool of handlers, with a capacity of the number of threads or something? If we do that, we should disable tokio's threaded scheduler by default.
    let (tx, mut rx) = handle::spawn(Default::default());
    let _res = tokio::join![
	tokio::spawn(async move {
	    for file in ["./src/main.rs", "./src/handle.rs", "./target", "./tet", "./"]
	    {
		eprintln!("Sending {}", file);
		tx.send(std::path::Path::new(file).into()).await.unwrap();
	    }
	}),
	tokio::spawn(async move {
	    use futures::prelude::*;
	    while let Some((file, hash)) = rx.next().await {
		println!("Got file hash for {:?}: {:?}", file, hash.map(|x| x.as_ref().iter().copied().hex_string().collect::<String>()));
	    }
	}),
    ];
    eprintln!("Done: {:?}", _res);
}
